==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridValidationServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridValidationServiceDescription } from "./WebGridValidationServiceDescription";
/**
 * @hidden
 */
export let WebGridValidationServiceDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridValidationServiceDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridValidationServiceDescriptionMetadata.a == null) {
                WebGridValidationServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridValidationServiceDescriptionMetadata.c(WebGridValidationServiceDescriptionMetadata.a);
            }
            if (a.j(WebGridValidationServiceDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridValidationServiceDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridValidationService");
            a.item("__packageNameWC", "String:grids");
        }
        static d(a) {
            WebGridValidationServiceDescriptionMetadata.b(a);
            a.aa("WebGridValidationService", () => new WebGridValidationServiceDescription());
            a.z("WebGridValidationService", WebGridValidationServiceDescriptionMetadata.a);
        }
    }
    WebGridValidationServiceDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridValidationServiceDescriptionMetadata, 'WebGridValidationServiceDescriptionMetadata');
    WebGridValidationServiceDescriptionMetadata.a = null;
    return WebGridValidationServiceDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridValidationServiceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridValidationServiceDescription } from "./WebGridValidationServiceDescription";
/**
 * @hidden
 */
export let WebGridValidationServiceDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridValidationServiceDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridValidationServiceDescriptionMetadata.a == null) {
                WebGridValidationServiceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridValidationServiceDescriptionMetadata.c(WebGridValidationServiceDescriptionMetadata.a);
            }
            if (a.k(WebGridValidationServiceDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridValidationServiceDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridValidationService");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        }
        static d(a) {
            WebGridValidationServiceDescriptionMetadata.b(a);
            a.ac("WebGridValidationService", () => new WebGridValidationServiceDescription());
            a.ab("WebGridValidationService", WebGridValidationServiceDescriptionMetadata.a);
        }
    }
    WebGridValidationServiceDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridValidationServiceDescriptionMetadata, 'WebGridValidationServiceDescriptionMetadata');
    WebGridValidationServiceDescriptionMetadata.a = null;
    return WebGridValidationServiceDescriptionMetadata;
})();
